@@ -11,18 +11,20 @@ from google.oauth2.credentials import Credentials
 from google_auth_oauthlib.flow import InstalledAppFlow
 
 from ..base import BasePlatformClient
-from ..transport_cache import TransportSetupCache
 from ...auth.wallets import get_wallet_class, LocalFileWallet
 from ...environment import Environment
 
 # Try importing Colab auth
+COLAB_AVAILABLE = False
 try:
     from google.colab import auth as colab_auth
     COLAB_AVAILABLE = True
 except ImportError:
     colab_auth = None
     COLAB_AVAILABLE = False
-
+except AttributeError:
+    colab_auth = None
+    COLAB_AVAILABLE = True
 
 class GooglePersonalClient(BasePlatformClient):
     """Client for personal Google accounts using OAuth2"""
@@ -37,24 +39,24 @@ class GooglePersonalClient(BasePlatformClient):
         'https://www.googleapis.com/auth/forms.body'
     ]
     
-    def __init__(self, email: str, verbose: bool = False, wizard: Optional[bool] = None, force_oauth: bool = False):
+    def __init__(self, email: str, verbose: bool = False, wizard: Optional[bool] = None, force_oauth: bool = False, init_transport: bool = True):
         super().__init__(email, verbose=verbose)
         self.platform = "google_personal"
         self.wizard = wizard
         self.force_oauth = force_oauth  # Force OAuth2 even in Colab
+        self.init_transport = init_transport
         
         # OAuth2 state
         self.credentials: Optional[Credentials] = None
         self.wallet = None
         
-        # Initialize setup cache
-        self.setup_cache = TransportSetupCache()
+        # Initialize transport layers if requested
+        if init_transport:
+            self._initialize_transport_layers()
+        else:
+            # Create uninitialized transport stubs
+            self._create_transport_stubs()
         
-        # Initialize transport layers
-        self._initialize_transport_layers()
-        
-        # Load cached setup status if available
-        self._load_cached_setup_status()
     
     def _initialize_transport_layers(self) -> None:
         """Initialize all transport layers for Google Personal"""
@@ -73,6 +75,21 @@ class GooglePersonalClient(BasePlatformClient):
         for transport in [self.gmail, self.gdrive_files, self.gsheets, self.gforms]:
             transport._platform_client = self
         
+        # In Colab, automatically setup transports that support Colab auth
+        if self.current_environment == Environment.COLAB:
+            # Setup non-Gmail transports with Colab auth
+            for transport_name, transport in [
+                ('gdrive_files', self.gdrive_files),
+                ('gsheets', self.gsheets),
+                ('gforms', self.gforms)
+            ]:
+                try:
+                    # Pass None to use Colab auth
+                    transport.setup(None)
+                except Exception:
+                    # Ignore setup failures (e.g., API not enabled)
+                    pass
+        
         # Keep transports dict for backward compatibility
         from ..base import TransportRegistry
         self.transports = TransportRegistry({
@@ -82,37 +99,425 @@ class GooglePersonalClient(BasePlatformClient):
             'gforms': self.gforms
         })
         
-        # Pass cache reference to TransportRegistry for __repr__
-        self.transports._setup_cache = self.setup_cache
+        # Pass references to TransportRegistry for __repr__
         self.transports._email = self.email
         self.transports._platform = self.platform
         self.transports._credentials_path = self.find_oauth_credentials()
     
-    def _load_cached_setup_status(self) -> None:
-        """Load cached transport setup status from disk"""
-        # Get credentials path for change detection
-        credentials_path = self.find_oauth_credentials()
+    def _create_transport_stubs(self) -> None:
+        """Create uninitialized transport stubs that require explicit setup"""
+        from ..base import TransportRegistry
         
-        # Check cache
-        cache_status = self.setup_cache.get_setup_status(
-            self.email, 
-            self.platform,
-            credentials_path
-        )
+        # Create wrapper class for uninitialized transports
+        class UninitializedTransport:
+            def __init__(self, transport_name: str, platform_client):
+                self._transport_name = transport_name
+                self._platform_client = platform_client
+                self._real_transport = None
+                self._setup_called = False
+                
+                # Set default attributes based on transport type
+                # These match the static attributes from the actual transport classes
+                if transport_name == 'gmail':
+                    self.is_keystore = True
+                    self.is_notification_layer = True
+                    self.is_html_compatible = True
+                    self.is_reply_compatible = True
+                    self.guest_submit = False
+                    self.guest_read_file = False
+                    self.guest_read_folder = False
+                elif transport_name == 'gdrive_files':
+                    self.is_keystore = True
+                    self.is_notification_layer = False
+                    self.is_html_compatible = False
+                    self.is_reply_compatible = False
+                    self.guest_submit = False
+                    self.guest_read_file = True
+                    self.guest_read_folder = True
+                elif transport_name == 'gsheets':
+                    self.is_keystore = True
+                    self.is_notification_layer = False
+                    self.is_html_compatible = False
+                    self.is_reply_compatible = False
+                    self.guest_submit = False
+                    self.guest_read_file = True
+                    self.guest_read_folder = False
+                elif transport_name == 'gforms':
+                    self.is_keystore = False
+                    self.is_notification_layer = False
+                    self.is_html_compatible = True
+                    self.is_reply_compatible = False
+                    self.guest_submit = True
+                    self.guest_read_file = False
+                    self.guest_read_folder = False
+                else:
+                    # Default values
+                    self.is_keystore = False
+                    self.is_notification_layer = False
+                    self.is_html_compatible = False
+                    self.is_reply_compatible = False
+                    self.guest_submit = False
+                    self.guest_read_file = False
+                    self.guest_read_folder = False
+                
+            def init(self, verbose: bool = True) -> bool:
+                """Initialize and set up this transport"""
+                from rich.console import Console
+                from rich.panel import Panel
+                
+                if verbose:
+                    # Show initialization start
+                    print(f"\nInitializing {self._transport_name} transport...")
+                
+                # Map transport names to their classes
+                transport_classes = {
+                    'gmail': lambda: __import__('syft_client.platforms.google_personal.gmail', fromlist=['GmailTransport']).GmailTransport,
+                    'gdrive_files': lambda: __import__('syft_client.platforms.google_personal.gdrive_files', fromlist=['GDriveFilesTransport']).GDriveFilesTransport,
+                    'gsheets': lambda: __import__('syft_client.platforms.google_personal.gsheets', fromlist=['GSheetsTransport']).GSheetsTransport,
+                    'gforms': lambda: __import__('syft_client.platforms.google_personal.gforms', fromlist=['GFormsTransport']).GFormsTransport,
+                }
+                
+                # Create the real transport
+                if verbose:
+                    print(f"  • Creating {self._transport_name} transport instance...")
+                transport_class = transport_classes[self._transport_name]()
+                self._real_transport = transport_class(self._platform_client.email)
+                self._real_transport._platform_client = self._platform_client
+                
+                # Replace ourselves in the platform client
+                setattr(self._platform_client, self._transport_name, self._real_transport)
+                self._platform_client.transports[self._transport_name] = self._real_transport
+                
+                # Set up with credentials if available
+                if hasattr(self._platform_client, 'credentials') and self._platform_client.credentials:
+                    if verbose:
+                        print("  • Setting up with OAuth2 credentials...")
+                    success = self._real_transport.setup({'credentials': self._platform_client.credentials})
+                    if success and verbose:
+                        print("  ✓ OAuth2 credentials configured")
+                    elif not success and verbose:
+                        print("  ✗ Failed to configure credentials")
+                else:
+                    if verbose:
+                        print("  • No credentials available (transport created but not authenticated)")
+                    success = True
+                
+                self._setup_called = True
+                
+                if success and verbose:
+                    # Create info panel with next steps
+                    info_lines = [
+                        f"[bold green]✓ {self._transport_name} transport initialized successfully![/bold green]",
+                        "",
+                        "[bold]What you can do now:[/bold]"
+                    ]
+                    
+                    # Add transport-specific suggestions
+                    if self._transport_name == 'gmail':
+                        info_lines.extend([
+                            "  • Send emails: [cyan].send(recipient, data, subject)[/cyan]",
+                            "  • Read emails: [cyan].receive(limit=10)[/cyan]",
+                            "  • Test setup: [cyan].test()[/cyan]"
+                        ])
+                    elif self._transport_name == 'gdrive_files':
+                        info_lines.extend([
+                            "  • List files: [cyan].list_files()[/cyan]",
+                            "  • Upload file: [cyan].upload_file(filepath)[/cyan]",
+                            "  • Download file: [cyan].download_file(file_id, save_path)[/cyan]"
+                        ])
+                    elif self._transport_name == 'gsheets':
+                        info_lines.extend([
+                            "  • Read sheet: [cyan].read_sheet(spreadsheet_id, range)[/cyan]",
+                            "  • Write data: [cyan].write_sheet(spreadsheet_id, range, values)[/cyan]",
+                            "  • Create sheet: [cyan].create_sheet(title)[/cyan]"
+                        ])
+                    elif self._transport_name == 'gforms':
+                        info_lines.extend([
+                            "  • List forms: [cyan].list_forms()[/cyan]",
+                            "  • Get responses: [cyan].get_responses(form_id)[/cyan]",
+                            "  • Create form: [cyan].create_form(title)[/cyan]"
+                        ])
+                    
+                    info_lines.extend([
+                        "",
+                        f"[dim]Access via: client.platforms.google_personal.{self._transport_name}[/dim]"
+                    ])
+                    
+                    # Use console only for the panel
+                    console = Console()
+                    panel = Panel("\n".join(info_lines), expand=False, border_style="green")
+                    print()  # Add spacing before panel
+                    console.print(panel)
+                
+                return success
+            
+            def is_setup(self) -> bool:
+                """Check if transport is set up"""
+                return self._setup_called and self._real_transport is not None
+            
+            @property
+            def login_complexity(self) -> int:
+                """Return the login complexity for this transport type"""
+                # All Google Personal transports have 0 additional complexity after OAuth2
+                return 0
+            
+            @classmethod
+            def check_api_enabled(cls, platform_client: Any) -> bool:
+                """Check if API is enabled - delegate to the real transport class"""
+                # Import the appropriate transport class and use its static method
+                transport_map = {
+                    'gmail': ('syft_client.platforms.google_personal.gmail', 'GmailTransport'),
+                    'gdrive_files': ('syft_client.platforms.google_personal.gdrive_files', 'GDriveFilesTransport'),
+                    'gsheets': ('syft_client.platforms.google_personal.gsheets', 'GSheetsTransport'),
+                    'gforms': ('syft_client.platforms.google_personal.gforms', 'GFormsTransport')
+                }
+                
+                # Get transport name from instance
+                if hasattr(cls, '_transport_name'):
+                    transport_name = cls._transport_name
+                else:
+                    # Try to infer from class
+                    return False
+                
+                if transport_name in transport_map:
+                    try:
+                        module_path, class_name = transport_map[transport_name]
+                        module = __import__(module_path, fromlist=[class_name])
+                        transport_class = getattr(module, class_name)
+                        return transport_class.check_api_enabled(platform_client)
+                    except:
+                        pass
+                return False
+            
+            def __repr__(self):
+                """String representation for uninitialized transport"""
+                from rich.console import Console
+                from rich.table import Table
+                from rich.panel import Panel
+                from io import StringIO
+                
+                # Create a string buffer to capture the rich output
+                string_buffer = StringIO()
+                console = Console(file=string_buffer, force_terminal=True, width=70)
+                
+                # Create main table
+                main_table = Table(show_header=False, show_edge=False, box=None, padding=0)
+                main_table.add_column("Attribute", style="bold cyan")
+                main_table.add_column("Value")
+                
+                # Transport initialization status
+                main_table.add_row(".is_initialized()", "[red]✗ Not initialized[/red]")
+                
+                # API status - check if API is enabled using the real transport's static method
+                api_status = "[dim]Unknown[/dim]"
+                try:
+                    # Import the real transport class
+                    transport_map = {
+                        'gmail': ('syft_client.platforms.google_personal.gmail', 'GmailTransport'),
+                        'gdrive_files': ('syft_client.platforms.google_personal.gdrive_files', 'GDriveFilesTransport'),
+                        'gsheets': ('syft_client.platforms.google_personal.gsheets', 'GSheetsTransport'),
+                        'gforms': ('syft_client.platforms.google_personal.gforms', 'GFormsTransport')
+                    }
+                    
+                    if self._transport_name in transport_map:
+                        module_path, class_name = transport_map[self._transport_name]
+                        module = __import__(module_path, fromlist=[class_name])
+                        transport_class = getattr(module, class_name)
+                        
+                        if transport_class.check_api_enabled(self._platform_client):
+                            api_status = "[green]✓ Enabled[/green]"
+                        else:
+                            api_status = "[red]✗ Disabled[/red]"
+                except:
+                    pass
+                main_table.add_row(".api_enabled", api_status)
+                
+                # Environment
+                from ...environment import detect_environment
+                env = detect_environment()
+                main_table.add_row(".environment", env.value if env else "Unknown")
+                
+                # Capabilities
+                main_table.add_row("", "")  # spacer
+                main_table.add_row("[bold]Capabilities[/bold]", "")
+                
+                # Show capabilities based on transport type
+                capabilities = [
+                    (".is_keystore", self.is_keystore),
+                    (".is_notification_layer", self.is_notification_layer),
+                    (".is_html_compatible", self.is_html_compatible),
+                    (".is_reply_compatible", self.is_reply_compatible),
+                    (".guest_submit", self.guest_submit),
+                    (".guest_read_file", self.guest_read_file),
+                    (".guest_read_folder", self.guest_read_folder),
+                ]
+                
+                for attr_name, value in capabilities:
+                    icon = "[green]✓[/green]" if value else "[dim]✗[/dim]"
+                    main_table.add_row(f"  {attr_name}", icon)
+                
+                # Complexity
+                main_table.add_row("", "")  # spacer
+                main_table.add_row(".login_complexity", f"{self.login_complexity} steps")
+                
+                # Key methods
+                main_table.add_row("", "")  # spacer
+                main_table.add_row("[bold]Methods[/bold]", "")
+                main_table.add_row("  .init()", "Initialize transport")
+                main_table.add_row("  .enable_api()", "Show enable instructions")
+                main_table.add_row("  .disable_api()", "Show disable instructions")
+                
+                # Get platform name
+                platform_name = getattr(self._platform_client, 'platform', 'unknown')
+                
+                # Create the panel
+                panel = Panel(
+                    main_table,
+                    title=f"client.platforms.{platform_name}.{self._transport_name}",
+                    expand=False,
+                    width=70,
+                    padding=(1, 2),
+                    border_style="yellow"  # Yellow to indicate caution - not initialized
+                )
+                
+                console.print(panel)
+                output = string_buffer.getvalue()
+                string_buffer.close()
+                
+                return output.strip()
+            
+            def enable_api(self) -> None:
+                """Show instructions for enabling the API"""
+                # Import the appropriate transport class and call its static method
+                transport_map = {
+                    'gmail': ('syft_client.platforms.google_personal.gmail', 'GmailTransport'),
+                    'gdrive_files': ('syft_client.platforms.google_personal.gdrive_files', 'GDriveFilesTransport'),
+                    'gsheets': ('syft_client.platforms.google_personal.gsheets', 'GSheetsTransport'),
+                    'gforms': ('syft_client.platforms.google_personal.gforms', 'GFormsTransport')
+                }
+                
+                if self._transport_name in transport_map:
+                    module_path, class_name = transport_map[self._transport_name]
+                    module = __import__(module_path, fromlist=[class_name])
+                    transport_class = getattr(module, class_name)
+                    transport_class.enable_api_static(self._transport_name, self._platform_client.email)
+            
+            def disable_api(self) -> None:
+                """Show instructions for disabling the API"""
+                # Import the appropriate transport class and call its static method
+                transport_map = {
+                    'gmail': ('syft_client.platforms.google_personal.gmail', 'GmailTransport'),
+                    'gdrive_files': ('syft_client.platforms.google_personal.gdrive_files', 'GDriveFilesTransport'),
+                    'gsheets': ('syft_client.platforms.google_personal.gsheets', 'GSheetsTransport'),
+                    'gforms': ('syft_client.platforms.google_personal.gforms', 'GFormsTransport')
+                }
+                
+                if self._transport_name in transport_map:
+                    module_path, class_name = transport_map[self._transport_name]
+                    module = __import__(module_path, fromlist=[class_name])
+                    transport_class = getattr(module, class_name)
+                    transport_class.disable_api_static(self._transport_name, self._platform_client.email)
+            
+            def test(self, test_data: str = "test123", cleanup: bool = True):
+                """Test transport - requires initialization first"""
+                if not self._setup_called or not self._real_transport:
+                    print(f"❌ Transport '{self._transport_name}' is not initialized")
+                    print(f"   Please call .init() first to initialize the transport")
+                    return {"success": False, "error": "Transport not initialized"}
+                
+                # Delegate to real transport
+                if hasattr(self._real_transport, 'test'):
+                    return self._real_transport.test(test_data=test_data, cleanup=cleanup)
+                else:
+                    return {"success": False, "error": f"Transport '{self._transport_name}' does not support test()"}
+            
+            def __getattr__(self, name):
+                # List of attributes that should be accessible without initialization
+                allowed_attrs = [
+                    'init', 'setup', 'is_setup', '_transport_name', '_platform_client', 
+                    '_real_transport', '_setup_called', 'login_complexity',
+                    'is_keystore', 'is_notification_layer', 'is_html_compatible',
+                    'is_reply_compatible', 'guest_submit', 'guest_read_file', 
+                    'guest_read_folder', 'enable_api', 'disable_api', 'test'
+                ]
+                
+                # Service attributes that should return None when not initialized
+                service_attrs = ['gmail_service', 'drive_service', 'sheets_service', 'forms_service']
+                
+                if name in allowed_attrs:
+                    return object.__getattribute__(self, name)
+                
+                # For service attributes, return None if not initialized
+                if name in service_attrs:
+                    if not self._setup_called:
+                        return None
+                    elif self._real_transport:
+                        return getattr(self._real_transport, name, None)
+                    else:
+                        return None
+                
+                if not self._setup_called:
+                    raise RuntimeError(f"Transport '{self._transport_name}' is not initialized. Please call .init() first.")
+                if self._real_transport:
+                    return getattr(self._real_transport, name)
+                raise AttributeError(f"'{self.__class__.__name__}' object has no attribute '{name}'")
         
-        if cache_status:
-            # Mark transports as set up based on cache
-            configured = set(cache_status.get('configured_transports', []))
-            
-            for transport_name in configured:
-                if transport_name in self.transports:
-                    transport = self.transports[transport_name]
-                    # Mark as setup verified (this is what is_setup() checks)
-                    transport._setup_verified = True
-            
-            if self.verbose:
-                hours_ago = int((datetime.now() - datetime.fromisoformat(cache_status['last_verified'])).total_seconds() / 3600)
-                print(f"✓ Loaded cached setup status ({hours_ago}h ago)")
+        # Create stub instances
+        self.gmail = UninitializedTransport('gmail', self)
+        self.gdrive_files = UninitializedTransport('gdrive_files', self)
+        self.gsheets = UninitializedTransport('gsheets', self)
+        self.gforms = UninitializedTransport('gforms', self)
+        
+        # Create transports registry
+        self.transports = TransportRegistry({
+            'gmail': self.gmail,
+            'gdrive_files': self.gdrive_files,
+            'gsheets': self.gsheets,
+            'gforms': self.gforms
+        })
+        
+        # Pass references to TransportRegistry for __repr__
+        self.transports._email = self.email
+        self.transports._platform = self.platform
+        self.transports._credentials_path = self.find_oauth_credentials()
+    
+    def initialize_transport(self, transport_name: str) -> bool:
+        """Initialize a single transport layer"""
+        if not hasattr(self, 'transports'):
+            from ..base import TransportRegistry
+            self.transports = TransportRegistry({})
+        
+        # Map transport names to their classes
+        transport_map = {
+            'gmail': lambda: __import__('syft_client.platforms.google_personal.gmail', fromlist=['GmailTransport']).GmailTransport,
+            'gdrive_files': lambda: __import__('syft_client.platforms.google_personal.gdrive_files', fromlist=['GDriveFilesTransport']).GDriveFilesTransport,
+            'gsheets': lambda: __import__('syft_client.platforms.google_personal.gsheets', fromlist=['GSheetsTransport']).GSheetsTransport,
+            'gforms': lambda: __import__('syft_client.platforms.google_personal.gforms', fromlist=['GFormsTransport']).GFormsTransport,
+        }
+        
+        if transport_name not in transport_map:
+            raise ValueError(f"Unknown transport: {transport_name}")
+        
+        # Create the transport instance
+        transport_class = transport_map[transport_name]()
+        transport = transport_class(self.email)
+        transport._platform_client = self
+        
+        # Add to transports registry and as attribute
+        self.transports[transport_name] = transport
+        setattr(self, transport_name, transport)
+        
+        # Update registry references
+        self.transports._email = self.email
+        self.transports._platform = self.platform
+        self.transports._credentials_path = self.find_oauth_credentials()
+        
+        # Set up the transport with credentials if available
+        if hasattr(self, 'credentials') and self.credentials:
+            return transport.setup({'credentials': self.credentials})
+        
+        return True
+    
     
     # ===== Core Authentication Methods (Main Flow) =====
     
@@ -139,38 +544,31 @@ class GooglePersonalClient(BasePlatformClient):
                     is_first_time = not config.get('setup_completed', False)
                     
                     if is_first_time:
-                        # Setup transport layers (but only non-Gmail ones will work)
-                        if self.verbose:
-                            print("\n⚠️  Note: Gmail requires OAuth2 setup and won't work with Colab auth")
-                            print("   Other services (Drive, Sheets, Forms) will work automatically")
-                        
-                        # In Colab, skip wizard unless explicitly requested
-                        show_wizard = self.wizard if self.wizard is not None else False
-                        transport_result = self.setup_transport_layers(show_wizard=show_wizard)
+                        if self.init_transport:
+                            # Setup transport layers (but only non-Gmail ones will work)
+                            if self.verbose:
+                                print("\n⚠️  Note: Gmail requires OAuth2 setup and won't work with Colab auth")
+                                print("   Other services (Drive, Sheets, Forms) will work automatically")
+                            
+                            # In Colab, skip wizard unless explicitly requested
+                            show_wizard = self.wizard if self.wizard is not None else False
+                            transport_result = self.setup_transport_layers(show_wizard=show_wizard)
+                            
+                            successful_transports = transport_result.get('configured', [])
+                            failed_transports = transport_result.get('failed', [])
+                        else:
+                            # Skip transport setup when init_transport=False
+                            successful_transports = []
+                            failed_transports = []
                         
                         # Mark setup as completed
                         config['setup_completed'] = datetime.now().isoformat()
                         config['colab_auth'] = True
                         self.save_platform_config(config)
-                        
-                        successful_transports = transport_result.get('configured', [])
-                        failed_transports = transport_result.get('failed', [])
                     else:
                         successful_transports = []
                         failed_transports = []
                     
-                    # Save setup status to cache for Colab
-                    if successful_transports:
-                        self.setup_cache.save_setup_status(
-                            email=self.email,
-                            platform=self.platform,
-                            configured_transports=set(successful_transports),
-                            credentials_path=None,  # No credentials file in Colab
-                            metadata={
-                                'auth_method': 'colab',
-                                'wallet': 'colab_builtin'
-                            }
-                        )
                     
                     return {
                         'email': self.email,
@@ -209,73 +607,51 @@ class GooglePersonalClient(BasePlatformClient):
                 if not config.get('wallet_config'):
                     self.configure_wallet_preference()
                 
-                # Step 7: Setup transport layers for first-time users
-                # For non-Colab, default to showing wizard unless wizard=False
-                show_wizard = self.wizard if self.wizard is not None else True
-                transport_result = self.setup_transport_layers(show_wizard=show_wizard)
+                if self.init_transport:
+                    # Step 7: Setup transport layers for first-time users
+                    # For non-Colab, default to showing wizard unless wizard=False
+                    show_wizard = self.wizard if self.wizard is not None else True
+                    transport_result = self.setup_transport_layers(show_wizard=show_wizard)
+                    
+                    successful_transports = transport_result.get('configured', [])
+                    failed_transports = transport_result.get('failed', [])
+                else:
+                    # Skip transport setup when init_transport=False
+                    successful_transports = []
+                    failed_transports = []
                 
                 # Mark setup as completed
                 config['setup_completed'] = datetime.now().isoformat()
                 self.save_platform_config(config)
-                
-                successful_transports = transport_result.get('configured', [])
-                failed_transports = transport_result.get('failed', [])
             else:
-                # For returning users, check cache first to avoid re-verification
-                successful_transports = []
-                failed_transports = []
-                
-                # Get credentials path for cache checking
-                credentials_path = self.find_oauth_credentials()
-                
-                for transport_name, transport in self.transports.items():
-                    # Check cache first
-                    if self.setup_cache.is_transport_setup_cached(
-                        self.email, 
-                        self.platform, 
-                        transport_name,
-                        credentials_path
-                    ):
-                        # Transport is cached as configured, but still need to initialize
-                        try:
-                            setup_data = {'credentials': self.credentials}
-                            if transport.setup(setup_data):
-                                successful_transports.append(transport_name)
-                                if self.verbose:
-                                    print(f"✓ {transport_name} already configured (cached)")
-                            else:
+                # For returning users
+                if self.init_transport:
+                    # Check and setup transports
+                    successful_transports = []
+                    failed_transports = []
+                    
+                    for transport_name, transport in self.transports.items():
+                        if hasattr(transport, 'is_setup') and transport.is_setup():
+                            # Transport reports it's already setup
+                            successful_transports.append(transport_name)
+                        else:
+                            # Try to set it up
+                            try:
+                                setup_data = {'credentials': self.credentials}
+                                if transport.setup(setup_data):
+                                    successful_transports.append(transport_name)
+                                else:
+                                    failed_transports.append(transport_name)
+                            except Exception:
                                 failed_transports.append(transport_name)
-                        except Exception:
-                            failed_transports.append(transport_name)
-                    elif hasattr(transport, 'is_setup') and transport.is_setup():
-                        # Transport reports it's setup (but not in cache)
-                        successful_transports.append(transport_name)
-                    else:
-                        # Try to set it up
-                        try:
-                            setup_data = {'credentials': self.credentials}
-                            if transport.setup(setup_data):
-                                successful_transports.append(transport_name)
-                            else:
-                                failed_transports.append(transport_name)
-                        except Exception:
-                            failed_transports.append(transport_name)
+                else:
+                    # Skip transport setup when init_transport=False
+                    successful_transports = []
+                    failed_transports = []
             
-            if not successful_transports:
+            if self.init_transport and not successful_transports:
                 raise ValueError("Failed to setup any transport layers")
             
-            # Save setup status to cache
-            credentials_path = self.find_oauth_credentials()
-            self.setup_cache.save_setup_status(
-                email=self.email,
-                platform=self.platform,
-                configured_transports=set(successful_transports),
-                credentials_path=credentials_path,
-                metadata={
-                    'auth_method': 'oauth2',
-                    'wallet': self.wallet.name if self.wallet else None
-                }
-            )
             
             if self.verbose:
                 print(f"\n✅ Authentication complete!")
@@ -341,6 +717,21 @@ class GooglePersonalClient(BasePlatformClient):
         Returns:
             bool: True if successful, False otherwise
         """
+
+        # Try importing Colab auth
+        try:
+            from google.colab import auth as colab_auth
+            COLAB_AVAILABLE = True
+        except ImportError:
+            colab_auth = None
+            COLAB_AVAILABLE = False
+        except AttributeError:
+            colab_auth = None # this will fail if we get the attribute error... 
+            # but i think that only comes up as a background atsk
+            # and background tasks shoudl only start after colab has logged in
+            # and in that case there should be a cached key instead of colab authentication
+            COLAB_AVAILABLE = False
+            
         if not COLAB_AVAILABLE or self.current_environment != Environment.COLAB:
             return False
         
@@ -677,7 +1068,7 @@ class GooglePersonalClient(BasePlatformClient):
             print("\n🔧 OAuth2 credentials not found. Starting setup wizard...")
         
         # Run the wizard
-        creds_file = check_or_create_credentials(self.email, self.verbose, self.force_oauth)
+        creds_file = check_or_create_credentials(email=self.email, verbose=self.verbose)
         
         if not creds_file:
             if self.verbose:
@@ -919,18 +1310,6 @@ class GooglePersonalClient(BasePlatformClient):
         
         transport = self.transports[name]
         
-        # Check cache first
-        credentials_path = self.find_oauth_credentials()
-        if self.setup_cache.is_transport_setup_cached(
-            self.email, 
-            self.platform, 
-            name,
-            credentials_path
-        ):
-            if self.verbose:
-                print(f"✓ {name} is already configured (cached)!")
-            return True
-        
         # Check if already configured
         if hasattr(transport, 'is_setup') and transport.is_setup():
             if self.verbose:
@@ -1054,7 +1433,14 @@ class GooglePersonalClient(BasePlatformClient):
     
     def get_transport_layers(self) -> List[str]:
         """Get list of available transport layers"""
-        return list(self.transports.keys())
+        # Always return what transports are available for this platform
+        # whether they're initialized or not
+        if hasattr(self, 'transports') and self.transports:
+            return list(self.transports.keys())
+        else:
+            # Return what would be available if initialized
+            return ['gmail', 'gdrive_files', 'gsheets', 'gforms']
+    
     
     # get_transport_instances() is now inherited from BasePlatformClient
     
